//
//  ContentView.swift
//  UICurrency
//
//  Created by Joe Gregg on 8/8/22.
//

import SwiftUI

struct ContentView: View {
    @FocusState private var amountIsFocused: Bool
    @State var current : String
    @State private var amount : String = "0.00"
    @State private var convertedAmount : String = "0.00"
    let rates = ["EUR":0.9829,"GBP":0.8397,"JPY":135.72,"CAD":1.3049]
    var keys : Array<String> {
        return Array(rates.keys)
    }
    
    func convert() -> String {
        let dollars : Double = Double(amount) ?? 0.0
        let amt = dollars * (rates[current] ?? 0.0)
        return String(format: "%.2f",amt)
    }
    
    var body: some View {
        NavigationStack {
            VStack {
                HStack {
                    TextField("",text:$amount)
                        .keyboardType(.decimalPad)
                        .textFieldStyle(.roundedBorder)
                        .focused($amountIsFocused)
                    Text("USD")
                }.padding()
                Button("Convert") {
                    convertedAmount = convert()
                    amountIsFocused = false
                }.buttonStyle(.bordered).padding()
                Text("\(convertedAmount) \(current)").padding()
            }
            .onAppear() { convertedAmount = convert() }
            .navigationTitle("Travel Money")
            .navigationBarTitleDisplayMode(.inline)
            .navigationBarItems(
                  trailing: NavigationLink("Currency") {
                          CurrencyList(currencies:keys,selected:$current)
                     }
                  )
        }
    }
}

#Preview {
    ContentView(current:"EUR")
}
